# A Note on Vibe Coding

Wasot was initially written in Go without vibe coding.
Then I have rewritten it in Rust using Claude Code.
New features were added, with me and Claude together.
I micromanaged Claude in great detail and reviewed every line.
While I did not write much Rust code, I did come up with all the ideas and how to implement them.
So Claude was merely the code generator.

For learning resources about the codebase, see [learning](./learning.md). For how files are organized in a [project](./project.md), see the project documentation.
